"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const client_1 = require("@apollo/client");
// Optimistic response generation utility method
//
function generateOptimisticResponseForMutation({ operationType, entityName, objects }) {
    const optimisticResponse = {
        __typename: "mutation_root",
        [`${operationType}_${entityName}`]: {
            affected_rows: objects.length,
            returning: objects.map(entity => {
                return { ...entity, __typename: entityName };
            }),
            __typename: `\${entityName}_mutation_response`
        }
    };
    return optimisticResponse;
}
exports.generateOptimisticResponseForMutation = generateOptimisticResponseForMutation;
/**
 *
 * @param param0
 */
function generateUpdateFunctionForMutation({ operationType, entityName, entityId }) {
    return (cache, result) => {
        cache.evict(client_1.defaultDataIdFromObject({ __typename: entityName, id: entityId }));
    };
}
exports.generateUpdateFunctionForMutation = generateUpdateFunctionForMutation;
function IS_JAVASCRIPT_SCALAR_EQUIVALENT(arg, includeNull = false) {
    var type = typeof arg;
    return (includeNull && arg === null) || (type != "object" && type != "function");
}
exports.IS_JAVASCRIPT_SCALAR_EQUIVALENT = IS_JAVASCRIPT_SCALAR_EQUIVALENT;
function IS_APOLLO_OBJECT(o) {
    return o && o.id && o.__typename;
}
exports.IS_APOLLO_OBJECT = IS_APOLLO_OBJECT;
function IS_NON_NULL_OBJECT(o) {
    return typeof o === "object" && o !== null;
}
exports.IS_NON_NULL_OBJECT = IS_NON_NULL_OBJECT;
function IS_OBJECT_WITH_ID(o) {
    return IS_NON_NULL_OBJECT(o) && o.id;
}
exports.IS_OBJECT_WITH_ID = IS_OBJECT_WITH_ID;
function IS_INSERT_INPUT_OBJECT(o) {
    if (!IS_NON_NULL_OBJECT(o))
        return false;
    return o.data;
}
exports.IS_INSERT_INPUT_OBJECT = IS_INSERT_INPUT_OBJECT;
function convertApolloObjectToRefObj(o) {
    if (!IS_APOLLO_OBJECT(o))
        throw new Error(`Provided object was not of type ApolloObject (with id & _typename properties): ${JSON.stringify(o)}`);
    return { id: o.id, __typename: o.__typeName };
}
exports.convertApolloObjectToRefObj = convertApolloObjectToRefObj;
function convertApolloObjectArrayToRefObj(o) {
    return o.map(arrayItem => convertApolloObjectToRefObj(o));
}
exports.convertApolloObjectArrayToRefObj = convertApolloObjectArrayToRefObj;
function recursiveConvertObjectWithIdToFragmentLikeObject({ o, typename, refTypeMap }) {
    if (!IS_OBJECT_WITH_ID(o))
        throw new Error(`Provided object was not of type ObjectWithId: ${JSON.stringify(o)}`);
    return { ...convertInsertInputToPartialFragmentResursive({ insertInputType: o, refTypeMap }), __typename: typename };
}
exports.recursiveConvertObjectWithIdToFragmentLikeObject = recursiveConvertObjectWithIdToFragmentLikeObject;
function convertObjectWithIdArrayToFragmentLikeArray({ o, typename, refTypeMap }) {
    return o.map(arrayItem => recursiveConvertObjectWithIdToFragmentLikeObject({ o: arrayItem, typename, refTypeMap }));
}
exports.convertObjectWithIdArrayToFragmentLikeArray = convertObjectWithIdArrayToFragmentLikeArray;
function recursiveConvertToFragmentLikeObject({ o, typename, refTypeMap, recursiveInsertInputTypeTest = true }) {
    if (!IS_NON_NULL_OBJECT(o))
        return null;
    if (Array.isArray(o)) {
        if (o.length === 0 || !o[0] || !IS_OBJECT_WITH_ID(o[0]))
            return null;
        return convertObjectWithIdArrayToFragmentLikeArray({ o, typename, refTypeMap });
    }
    if (IS_OBJECT_WITH_ID(o)) {
        return recursiveConvertObjectWithIdToFragmentLikeObject({ o, typename, refTypeMap });
    }
    //if here, might be a InsertInput object, which has the payload in a property named data
    if (recursiveInsertInputTypeTest && IS_INSERT_INPUT_OBJECT(o)) {
        return recursiveConvertToFragmentLikeObject({ o: o.data, typename, refTypeMap, recursiveInsertInputTypeTest: false });
    }
    // if non of the above, return null
    return null;
}
function convertInsertInputToPartialFragmentResursive({ insertInputType, refTypeMap }) {
    const fragment = {};
    //Loop object and build up a fragment appropriate for a cache-add
    for (const [insertInputKey, insertInputValue] of Object.entries(insertInputType)) {
        //Add scalar values
        if (IS_JAVASCRIPT_SCALAR_EQUIVALENT(insertInputValue)) {
            fragment[insertInputKey] = insertInputValue;
            continue;
        }
        if (IS_NON_NULL_OBJECT(insertInputValue) && refTypeMap && refTypeMap[insertInputKey]) {
            const ref = recursiveConvertToFragmentLikeObject({ o: insertInputValue, typename: refTypeMap[insertInputKey], refTypeMap });
            if (ref) {
                fragment[insertInputKey] = ref;
                continue;
            }
        }
    }
    return fragment;
}
exports.convertInsertInputToPartialFragmentResursive = convertInsertInputToPartialFragmentResursive;
//# sourceMappingURL=utils.js.map